nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

BaseAddr0

Struct BaseAddr0 

#[repr(transparent)]
pub struct BaseAddr0(pub u32);
Base Address for region 0 register

Tuple Fields

0: u32

Implementations

Source

impl BaseAddr0

pub const fn addr_fixed(&self) -> u32

Fixed portion of the base address of region 0.

pub const fn set_addr_fixed(&mut self, val: u32)

Fixed portion of the base address of region 0.

pub const fn addr_prg(&self) -> u8

Programmable portion of the base address of region 0.

pub const fn set_addr_prg(&mut self, val: u8)

Programmable portion of the base address of region 0.