#[repr(transparent)]pub struct BaseAddr2(pub u32);Expand description
Base Address for region 2 register
Tuple Fields
0: u32Implementations
Sourceimpl BaseAddr2
impl BaseAddr2
Sourcepub const fn addr_fixed(&self) -> u32
pub const fn addr_fixed(&self) -> u32
Fixed portion of the base address of region 2.
Sourcepub const fn set_addr_fixed(&mut self, val: u32)
pub const fn set_addr_fixed(&mut self, val: u32)
Fixed portion of the base address of region 2.
Sourcepub const fn set_addr_prg(&mut self, val: u8)
pub const fn set_addr_prg(&mut self, val: u8)
Programmable portion of the base address of region 2.